<?php
$config = get_option('my_framework');
$default_light_theme = $config['lightMode'];
$output = $default_light_theme ? 'class="light"' : '';
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?> <?= $output; ?>>

<head>
  <meta charset="UTF-8">
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <?php if ($config['favicon']['url']) : ?>
    <link rel="icon" type="image" href="<?php echo $config['favicon']['url']; ?> " />
  <?php endif; ?>
  <?php if ($config['pwa_active']): ?>
   <!-- PWA -->
   <link rel="manifest" href="<?php bloginfo('url'); ?>/manifest.json">
    <?php if($config['pwa_icon_1']['url']): ?>
    <link rel="apple-touch-icon" href="<?= $config['pwa_icon_1']['url']; ?>" />
    <?php endif; ?> 
    <?php if($config['pwa_icon_2']['url']): ?>
    <link rel="apple-touch-icon" href="<?= $config['pwa_icon_2']['url']; ?>" />
    <?php endif; ?> 
    <?php if($config['status_color']): ?>
    <meta name="apple-mobile-web-app-status-bar" content="<?= $config['status_color'] ?>" />
    <?php endif; ?> 
    <?php if($config['theme_pwa_color']): ?>
    <meta name="theme-color" content="<?= $config['theme_pwa_color'] ?>" />
    <?php endif;
    endif;
    ?> 
  <?php wp_head();
  if (is_single()) {
    wp_enqueue_script('comment-reply');
    // count post views
    setPostViewCount();
  }
  ?>
  <script>
    var body = document.querySelector('html');
    
    if (localStorage.getItem("theme")) {
      var theme = localStorage.getItem("theme");
    }
    if (theme == "light") {
      body.classList.add("light");
    } else if (theme == "dark") {
      body.classList.remove("light");
    }
  </script>
  <style>
    :root{
      --primaryColor: <?= $config['theme_color'] ?>;
      --secondaryColor: <?= $config['theme_color2'] ?>;
      --primaryTextBtn: <?= $config['theme_text_color'] ?>;
      --primaryColorLight: <?= $config['theme_color'] ?>24;
      --plyr-color-main: <?= $config['theme_color'] ?>;
    }
    body{
      font-family: <?= $config['font'];?>;
    }
  </style>
</head>
<body <?php body_class()?>>
<?php if($config['preloader']): ?>
<div class="preload">
  <div class="spin_wrap">
    <div class="lds-ripple"><div></div><div></div></div>
    <?php _e('درحال بارگذاری...', 'musicsara') ?>
  </div>
</div>
<?php endif; ?>

<?php if ($config['adminNotice']) : ?>
  <div class="adminNotice <?php echo $config['adminNotice_location'] ? 'adminNotice_down' : 'adminNotice_up'  ?>" class="adminNotice">
    <div class="<?php musicsara_container_class(); ?> d-flex justify-content-between fixMobile">
      <div class="align-right">
        <i id="dismissNotice" class="bi bi-x-lg dismiss"></i>
        <span><?= $config['adminNotice_text'] ?></span>
      </div>
      <div class="adminNotice__btn">
        <a href="<?= $config['adminNotice_btnLink'] ?>"><?= $config['adminNotice_btnText'] ?></a>
      </div>
    </div>
  </div>
<?php endif; ?>


<?php if (!function_exists('elementor_theme_do_location') || !elementor_theme_do_location('header')) :?>
  <header class="header stick_header">
  <div class="<?php musicsara_container_class(); ?> d-flex justify-content-between align-items-center">
    <button data-bs-toggle="offcanvas" data-bs-target="#offcanvasRight" aria-controls="offcanvasRight" aria-label="<?php _e('منو دسته بندی', 'musicsara') ?>" class="nav_trigger">
      <i class="bi bi-list"></i>
    </button>
    <a class="d-flex" href="<?php bloginfo('url') ?>">
      <div class="logo">
      <?php if ($config['logo_image']['url']) : ?>
      <img src="<?php echo $config['logo_image']['url']; ?>" alt="<?php bloginfo('name') ?>">
      <?php endif; ?>
      <span><?= $config['logo_text']; ?></span>
      </div>
    </a>
    <nav class="top_nav">
    <?php wp_nav_menu(array('theme_location' => 'category', 'container' => '', 'menu_class' => 'menunav')); ?>
    </nav>
    <div class="leftSide d-flex">
      <div class="login_register">
        <?php 
        if( WOOCOMMERCE_ACTIVE ):
          if(is_user_logged_in()): ?>
            <a href="<?php echo site_url() ?>/my-account"><i class="bi bi-person-fill"></i></a>
          <?php else: ?>
            <a href="<?php echo site_url() ?>/login"><i class="bi bi-person"></i></a>
          <?php endif; 
        endif;
        ?>
      </div>
      <div class="light_switch">
        <button aria-label="<?php _e('موزیک سرا', 'musicsara') ?>"><i class="bi bi-sun dark_toggle"></i></button>
      </div>
      <div class="search_mobile">
        <button aria-label="<?php _e('جستجو', 'musicsara') ?>" data-bs-toggle="offcanvas" data-bs-target="#offcanvasSearch" aria-controls="offcanvasSearch" class="search_trigger"><i class="bi bi-search"></i></button>
      </div>

      <div class="search_wrap">
        <form action="<?php echo bloginfo('url'); ?>">
          <input autocomplete="off" type="text" class="search__input ajax_search" value="<?php echo get_search_query(); ?>" placeholder="<?php _e('جستجو...', 'musicsara') ?>" name="s">
          <button aria-label="<?php _e('جستجو', 'musicsara') ?>" class="search_submit" type="submit"><i class="bi bi-search"></i></button>
          <div id="datafetch"></div>
        </form>
      </div>
    </div>
  </div>
</header>
<?php endif; ?>


<div class="offcanvas offcanvas-top menu_mobile" style="height: 130px" tabindex="-1" id="offcanvasSearch" aria-labelledby="offcanvasSearchLabel">
    <div class="offcanvas-header">
      <h5 id="offcanvasSearchLabel">
        <?php _e('جستجو', 'musicsara') ?>
      </h5>
      <button type="button" class="close_menu text-reset" data-bs-dismiss="offcanvas" aria-label="Close"><i class="bi bi-x-lg"></i></button>
    </div>
    <div class="offcanvas-body searchCanvas">
      <div class="d-flex justify-content-center">
        <form class="search_form" action="">
          <input type="hidden" value="advanced">
          <input type="text" class="search_input" name="s" placeholder="<?php _e('نام آهنگ، نام خواننده، نام آلبوم و...', 'musicsara') ?>">
          <button class="search_submit" type="submit"><i class="bi bi-search"></i></button>
        </form>
      </div>
    </div>
  </div>

  <div class="offcanvas offcanvas-end menu_mobile" tabindex="-1" id="offcanvasRight" aria-labelledby="offcanvasRightLabel">
    <div class="offcanvas-header">
      <h5 id="offcanvasRightLabel">
        <?= $config['logo_text'] ?>
      </h5>
      <button type="button" class="close_menu text-reset" data-bs-dismiss="offcanvas" aria-label="Close"><i class="bi bi-x-lg"></i></button>
    </div>
    <div class="offcanvas-body float_menu p-0">
      <?php wp_nav_menu(array('theme_location' => 'category', 'container' => '', 'menu_class' => 'menunav')); ?>
      <div class="mobile_actions">
      <?php if( WOOCOMMERCE_ACTIVE ): ?>
      <div class="login_register">
        <?php if(is_user_logged_in()): ?>
          <a href="<?php echo site_url() ?>/my-account"><i class="bi bi-person-fill"></i></a>
        <?php else: ?>
          <a href="<?php echo site_url() ?>/login"><i class="bi bi-person"></i></a>
        <?php endif; ?>
      </div>
      <?php endif; ?>
      <div class="light_switch">
        <button aria-label="<?php _e('تغییر تم', 'musicsara') ?>"><i class="bi bi-sun dark_toggle"></i></button>
      </div>
    </div>
    </div>
  </div>