<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor Slider Widget.
 *
 * @since 1.0.0
 */
class CarouselWidget extends \Elementor\Widget_Base {

  public function __construct($data = [], $args = null) {
    parent::__construct($data, $args);

    wp_register_script( 'elements', get_template_directory_uri() . '/assets/js/elements.js', [ 'elementor-frontend', 'swiper' ], '1.0.0', true );
  }

  public function get_script_depends() {
    return [ 'elements' ];
  }

	/**
	 * Get widget name.
	 *
	 * Retrieve widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'content_carousel';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'کروسل محتوا', 'musicsara' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-carousel';
	}

	/**
	 * Get custom help URL.
	 *
	 * Retrieve a URL where the user can get more information about the widget.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget help URL.
	 */
	public function get_custom_help_url() {
		return 'https://developers.elementor.com/docs/widgets/';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'musicsara' ];
	}

	/**
	 * Get widget keywords.
	 *
	 * Retrieve the list of keywords the widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return array Widget keywords.
	 */
	public function get_keywords() {
		return [ 'oembed', 'url', 'link' ];
	}

	/**
	 * Register oEmbed widget controls.
	 *
	 * Add input fields to allow the user to customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'تنظیمات محتوا', 'musicsara' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'carousel_title',
			[
				'label' => esc_html__( 'عنوان کروسل', 'musicsara' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);

    $this->add_control(
			'carousel_items',
			[
				'label' => esc_html__( 'تعداد مطالب', 'musicsara' ),
				'type' => \Elementor\Controls_Manager::TEXT,
        'default' => 10,
			]
		);

    $options = array();

    $args = array(
      'hide_empty' => false,
      'post_type'     => 'post',
      'taxonomy'  => 'category',
    );

    $categories = get_categories($args);

    foreach ($categories as $key => $category) {
      $options[$category->term_id] = $category->name;
    }
  
    $type_ = array();

    $musicsara_types = get_terms(array(
      'taxonomy'   => 'type_',
      'hide_empty' => false
    ));

    foreach ($musicsara_types as $key => $type) {
      $type_[$type->term_id] = $type->name;
    }

    $this->add_control(
      'category',
      [
        'label' => esc_html__('انتخاب دسته بندی', 'musicsara'),
        'type' => \Elementor\Controls_Manager::SELECT2,
        'multiple' => false,
        'description' => 'در صورت انتخاب دسته مطالب دسته و درصورت انتخاب نکردن آخرین مطالب نشان داده می‌شوند.',
        'options' => $options,
        'default' => [],
      ]
    );

    $this->add_control(
      'post_type',
      [
        'label' => esc_html__('انتخاب نوع پست', 'musicsara'),
        'type' => \Elementor\Controls_Manager::SELECT2,
        'multiple' => false,
        'description' => 'می‌توانید مطالب را بر اساس نوع پست نیز نمایش دهید. مثلا تک آهنگ ها موزیک ها و...',
        'options' => $type_,
        'default' => [],
      ]
    );

		$this->end_controls_section();
    
    $this->start_controls_section(
      'c_settings',
      [
        'label' => esc_html__('تنظیمات کروسل', 'elementor-ads-widget'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    $this->add_control(
      'card_style',
      [
        'label' => esc_html__('استایل کارت', 'musicsara'),
        'type' => \Elementor\Controls_Manager::SELECT2,
        'multiple' => false,
        'description' => 'طرح کارت های کروسل را انتخاب کنید.',
        'options' => [
          'default' => 'طرح پیشفرض',
          'spotify' => 'طرح اسپاتیفای',
          'minimal' => 'طرح مینیمال',
        ],
        'default' => 'default',
      ]
    );

    $this->add_control(
			'pagination_notice',
			[
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' =>  '<div>'. __('تنظیمات صفحه بندی و پیکان ها', 'sepidar') .'</div>',
				'content_classes' => 'sepidar_divider',
			]
		);

    $this->add_control(
			'show_pagination',
			[
				'label' => esc_html__( 'نمایش صفحه بندی', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
				'default' => 'yes',
        'frontend_available' => true
			]
		);

    $this->add_control(
			'show_next_prev',
			[
				'label' => esc_html__( 'نمایش دکمه بعدی قبلی', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
				'default' => 'yes',
        'frontend_available' => true
			]
		);

    $this->add_control(
			'carousel_items',
			[
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' =>  '<div>'. __('تنظیمات نمایش تعداد آیتم ها', 'sepidar') .'</div>',
				'content_classes' => 'sepidar_divider',
			]
		);


    $this->add_control(
      'el_desktop',
      [
        'label' => esc_html__('تعداد آیتم در دسکتاپ', 'elementor-oembed-widget'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'placeholder' => esc_html__('مثلا 6.3', 'elementor-oembed-widget'),
        'default' => '6.3',
        'frontend_available' => true,
        'description' => 'میتوانید از اعداد اعشاری برای نمایش بخشی از آیتم بعدی استفاده کنید مثلا ۶.۲  ۶محصول نمایش داده میشود و ۲۰٪ از آینم بعدی نیز نمایش داده میشود'
      ]
    );

    $this->add_control(
      'el_desktop_small',
      [
        'label' => esc_html__('تعداد آیتم در دسکتاپ کوچک', 'elementor-oembed-widget'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'placeholder' => esc_html__('مثلا 3.2', 'elementor-oembed-widget'),
        'default' => '4.2',
        'frontend_available' => true
      ]
    );

    $this->add_control(
      'el_tablet',
      [
        'label' => esc_html__('تعداد آیتم در تبلت', 'elementor-oembed-widget'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'placeholder' => esc_html__('مثلا 2.2', 'elementor-oembed-widget'),
        'default' => '2',
        'frontend_available' => true
      ]
    );

    $this->add_control(
      'el_mobile',
      [
        'label' => esc_html__('تعداد آیتم در موبایل', 'elementor-oembed-widget'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'placeholder' => esc_html__('مثلا 2.7', 'elementor-oembed-widget'),
        'default' => '1.5',
        'frontend_available' => true
      ]
    );

    $this->add_control(
			'carousel_autoplay_notice',
			[
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' =>  '<div>'. __('سایز تنظیمات کروسل', 'sepidar') .'</div>',
				'content_classes' => 'sepidar_divider',
			]
		);

    $this->add_control(
			'loop',
			[
				'label' => esc_html__( 'لوپ کردن آیتم های کروسل', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

    $this->add_control(
			'centeredSlides',
			[
				'label' => esc_html__( 'حرکت از آیتم وسط', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

    $this->add_control(
			'autoplay',
			[
				'label' => esc_html__( 'اتوپلی کردن آیتم ها', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

    $this->add_control(
			'autoplay_delay',
			[
				'label' => esc_html__( 'میزان تاخیر (ms)', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( '4000', 'textdomain' ),
        'condition' => [
          'autoplay' => 'yes',
        ],
				'placeholder' => esc_html__( 'بر اساس میلی ثانیه وارد کنید. هر ۱ثانیه معادل ۱۰۰۰ میلی ثانیه', 'textdomain' ),
			]
		);

    $this->end_controls_section();

	}

	/**
	 * Render widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();
		$title = $settings['carousel_title'];
    $category = $settings['category'];
    $post_type = $settings['post_type'];
    $show_buttons = $settings['show_next_prev'];

    $widget_id = $this->get_id();
    $options = array(
      'el_mobile' => $settings['el_mobile'],
      'el_desktop_small' => $settings['el_desktop_small'],
      'el_tablet' => $settings['el_tablet'],
      'el_desktop' => $settings['el_desktop'],
      'autoplay' => ($settings['autoplay'] == 'yes') ? 'true' : 'false',
      'loop' => ($settings['loop'] == 'yes') ? 'true' : 'false',
      'autoplay_delay' => $settings['autoplay_delay'] ? $settings['autoplay_delay'] : '5000',
      'centeredSlides' => $settings['centeredSlides'] == 'yes' ? 'true' : 'false'
    );
    ?>

<section id="musicsara_carousel_<?php echo $widget_id; ?>"
    data-options="<?php echo htmlspecialchars( json_encode($options) ) ?>"
    class="musicsara_carousel musicsara_content_carousel bg_color latestSongs mb-5">
  <div class="swiper">
    <div class="latestSongs__header d-flex justify-content-between">
      <h3><span class="indicator"></span>
      <?php echo $title; ?>
      </h3>
      <div class="button_wrap d-flex">
      <?php if($show_buttons): ?>
        <div class="button-prev"><i class="bi bi-chevron-right"></i></div>
        <div class="button-next"><i class="bi bi-chevron-left"></i></div>
      <?php endif;?>
      </div>
    </div>
    <div class="swiper-wrapper">
      <?php
      
      $args = array(
        'showposts' => $settings['carousel_items'],
      );

      if($category){
        $args['cat'] = $category;
      }

      if($post_type){
        $args['tax_query'] = array(
          array(
            'taxonomy' => 'type_',
            'field' => 'term_id',
            'terms' => $post_type
          ),
        );
      }

      $query = new WP_Query($args);
      if ($query->found_posts) :
        while ($query->have_posts()) :
          $query->the_post();
      ?>
        <div class="swiper-slide">
        <?php 
        if( $settings['card_style'] == 'default' ):
          get_template_part('inc/template_parts/cards/default.style');
        elseif( $settings['card_style'] == 'spotify' ):
          get_template_part('inc/template_parts/cards/spotify.style');
        elseif( $settings['card_style'] == 'minimal' ):
            get_template_part('inc/template_parts/cards/minimal.style');
        else:
          get_template_part('inc/template_parts/cards/default.style');
        endif;
        ?>
        </div>
      <?php
        endwhile;
      endif;
      wp_reset_postdata();
      ?>
    </div>
    <?php if( $settings['show_pagination'] === 'yes' ): ?>
      <div class="swiper-pagination"></div>
    <?php endif; ?>
  </div>
</section>

<?php
  }

}