<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor Slider Widget.
 *
 * @since 1.0.0
 */
class GenreWidget extends \Elementor\Widget_Base {

  public function __construct($data = [], $args = null) {
    parent::__construct($data, $args);

    wp_register_script( 'elements', get_template_directory_uri() . '/assets/js/elements.js', [ 'elementor-frontend', 'swiper' ], '1.0.0', true );
  }

  public function get_script_depends() {
    return [ 'elements' ];
  }

	/**
	 * Get widget name.
	 *
	 * Retrieve widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'genre_carousel';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'کروسل سبک های موسیقی', 'musicsara' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-slider-push';
	}

	/**
	 * Get custom help URL.
	 *
	 * Retrieve a URL where the user can get more information about the widget.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget help URL.
	 */
	public function get_custom_help_url() {
		return 'https://developers.elementor.com/docs/widgets/';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'musicsara' ];
	}

	/**
	 * Get widget keywords.
	 *
	 * Retrieve the list of keywords the widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return array Widget keywords.
	 */
	public function get_keywords() {
		return [ 'oembed', 'url', 'link' ];
	}

	/**
	 * Register oEmbed widget controls.
	 *
	 * Add input fields to allow the user to customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		$this->start_controls_section(
      'c_settings',
      [
        'label' => esc_html__('تنظیمات کروسل', 'elementor-ads-widget'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    $this->add_control(
			'pagination_notice',
			[
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' =>  '<div>'. __('تنظیمات صفحه بندی و پیکان ها', 'sepidar') .'</div>',
				'content_classes' => 'sepidar_divider',
			]
		);

    $this->add_control(
			'carousel_items',
			[
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' =>  '<div>'. __('تنظیمات نمایش تعداد آیتم ها', 'sepidar') .'</div>',
				'content_classes' => 'sepidar_divider',
			]
		);


    $this->add_control(
      'el_desktop',
      [
        'label' => esc_html__('تعداد آیتم در دسکتاپ', 'elementor-oembed-widget'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'placeholder' => esc_html__('مثلا 6.3', 'elementor-oembed-widget'),
        'default' => '6.3',
        'frontend_available' => true,
        'description' => 'میتوانید از اعداد اعشاری برای نمایش بخشی از آیتم بعدی استفاده کنید مثلا ۶.۲  ۶محصول نمایش داده میشود و ۲۰٪ از آینم بعدی نیز نمایش داده میشود'
      ]
    );

    $this->add_control(
      'el_desktop_small',
      [
        'label' => esc_html__('تعداد آیتم در دسکتاپ کوچک', 'elementor-oembed-widget'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'placeholder' => esc_html__('مثلا 3.2', 'elementor-oembed-widget'),
        'default' => '4.2',
        'frontend_available' => true
      ]
    );

    $this->add_control(
      'el_tablet',
      [
        'label' => esc_html__('تعداد آیتم در تبلت', 'elementor-oembed-widget'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'placeholder' => esc_html__('مثلا 2.2', 'elementor-oembed-widget'),
        'default' => '2',
        'frontend_available' => true
      ]
    );

    $this->add_control(
      'el_mobile',
      [
        'label' => esc_html__('تعداد آیتم در موبایل', 'elementor-oembed-widget'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'placeholder' => esc_html__('مثلا 2.7', 'elementor-oembed-widget'),
        'default' => '1.5',
        'frontend_available' => true
      ]
    );

    $this->add_control(
			'carousel_autoplay_notice',
			[
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' =>  '<div>'. __('سایز تنظیمات کروسل', 'sepidar') .'</div>',
				'content_classes' => 'sepidar_divider',
			]
		);

    $this->add_control(
			'loop',
			[
				'label' => esc_html__( 'لوپ کردن آیتم های کروسل', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
			]
		);

    $this->add_control(
			'centeredSlides',
			[
				'label' => esc_html__( 'حرکت از آیتم وسط', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
			]
		);

    $this->add_control(
			'autoplay',
			[
				'label' => esc_html__( 'اتوپلی کردن آیتم ها', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
			]
		);

    $this->add_control(
			'autoplay_delay',
			[
				'label' => esc_html__( 'میزان تاخیر (ms)', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( '4000', 'textdomain' ),
        'condition' => [
          'autoplay' => 'yes',
        ],
				'placeholder' => esc_html__( 'بر اساس میلی ثانیه وارد کنید. هر ۱ثانیه معادل ۱۰۰۰ میلی ثانیه', 'textdomain' ),
			]
		);

    $this->end_controls_section();

	}

	/**
	 * Render widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
    $widget_id = $this->get_id();
    $options = array(
      'el_mobile' => $settings['el_mobile'],
      'el_desktop_small' => $settings['el_desktop_small'],
      'el_tablet' => $settings['el_tablet'],
      'el_desktop' => $settings['el_desktop'],
      'autoplay' => ($settings['autoplay'] == 'yes') ? 'true' : 'false',
      'loop' => ($settings['loop'] == 'yes') ? 'true' : 'false',
      'autoplay_delay' => $settings['autoplay_delay'] ? $settings['autoplay_delay'] : '5000',
      'centeredSlides' => $settings['centeredSlides'] == 'yes' ? 'true' : 'false'
    );
    ?>

    <div
    id="musicsara_carousel_<?php echo $widget_id; ?>"
    data-options="<?php echo htmlspecialchars( json_encode($options) ) ?>"
    class="musicsara_carousel musicsara_genre_carousel genre">
      <div  dir="rtl" class="swiper genreSwiper">
        <div class="swiper-wrapper">
          <?php $genre = get_terms('genre', array('hide_empty' => false,));
          foreach ($genre as $g_item) : ?>
            <div class="swiper-slide">
            <a href="<?php bloginfo('url') ?>/genre/<?= $g_item->slug ?>"><?= $g_item->name ?></a>
            </div>
          <?php endforeach; ?>
        </div>
      </div>
    </div>

  <?php
	}

}