<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor Slider Widget.
 *
 * @since 1.0.0
 */
class RandomMusicWidget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'random_music';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'موزیک تصادفی', 'musicsara' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-play';
	}

	/**
	 * Get custom help URL.
	 *
	 * Retrieve a URL where the user can get more information about the widget.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget help URL.
	 */
	public function get_custom_help_url() {
		return 'https://developers.elementor.com/docs/widgets/';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'musicsara' ];
	}

	/**
	 * Get widget keywords.
	 *
	 * Retrieve the list of keywords the widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return array Widget keywords.
	 */
	public function get_keywords() {
		return [ 'oembed', 'url', 'link' ];
	}

	/**
	 * Register oEmbed widget controls.
	 *
	 * Add input fields to allow the user to customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'تنظیمات', 'musicsara' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'carousel_title',
			[
				'label' => esc_html__( 'عنوان', 'musicsara' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				// 'input_type' => 'text',
				// 'placeholder' => esc_html__( '', 'musicsara' ),
			]
		);

    $this->add_control(
      'special',
      [
        'label' => esc_html__('نمایش فقط مطالب ویژه', 'musicsara'),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__('بله', 'musicsara'),
        'label_off' => esc_html__('خیر', 'musicsara'),
        'return_value' => true,
        'default' => false,
      ]
    );

		$this->end_controls_section();
	}

	/**
	 * Render widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();
		$title = $settings['carousel_title'];
    $just_special = $settings['special'];
    ?>
  <section class="randomSong">
    <div class="randomSong__header d-flex justify-content-between">
      <h3><span class="indicator"></span>
      <?php echo $title; ?>
      </h3>
    </div>
    <?php
    $args = array(
      'showposts' => 1,
      'orderby' => 'rand',
      'tax_query' => array(
        array(
          'taxonomy' => 'type_',
          'field' => 'slug',
          'terms' => array('single'),
        ),
      )
    );

    if($just_special) {
      $args['meta_key'] = 'special';
      $args['meta_value'] = true;
    }

    $query = new WP_Query($args);
    if ($query->found_posts) :
      while ($query->have_posts()) :
        $query->the_post();
        global $post;
    ?>
        <div class="randomSong__inner position-relative">
          <div class="randomSong__like">
            <?php echo like_it_button_html('', $post); ?>
          </div>
          <div class="audio-player">
            <div class="icon-container">
              <a href="<?php the_permalink() ?>">
                <?php the_post_thumbnail('cover') ?>
              </a>
              <div class="randomSong_artist"><?php echo get_the_term_list(get_the_ID(), 'artist', '', ' ', ''); ?></div>
              <div class="randomSong_title"><?php the_field('title') ?></div>
              <?php if (get_field('download_320')) : ?>
                <audio controls id="audioPlayer" class="audio_home" preload="none" src="<?php the_field('download_320'); ?>"></audio>
              <?php endif; ?>
            </div>
          </div>
        </div>
    <?php
      endwhile;
    endif;
    wp_reset_postdata();
    ?>
  </section>

  <?php
	}

}