<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class DownloadLinksWidget extends \Elementor\Widget_Base {

	public function get_name() {
		return 'download_links';
	}

	public function get_title() {
		return esc_html__( 'لینک های دانلود', 'musicsara' );
	}

	public function get_icon() {
		return 'eicon-download-circle-o';
	}

	public function get_categories() {
		return [ 'musicsara' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'تنظیمات', 'musicsara' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

    $this->add_control(
			'style',
			[
				'label' => esc_html__( 'طرح لینک ها', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'modern',
				'options' => [
					'modern' =>'مدرن',
				],
			]
		);

    $this->add_control(
			'show_lyrics',
			[
				'label' => esc_html__( 'نمایش دکمه مشاهده متن اهنگ', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
				'default' => 'yes',
        'frontend_available' => true
			]
		);

		$this->end_controls_section();

    $this->start_controls_section(
			'style_section',
			[
				'label' => esc_html__( 'استایل', 'musicsara' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

    $this->add_control(
			'text_color',
			[
				'label' => esc_html__( 'رنگ متن', 'sepidar' ),
				'type' => Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .download a' => 'color: {{VALUE}};',
				],
			]
		);

    $this->add_control(
			'bg_color',
			[
				'label' => esc_html__( 'رنگ پس زمینه', 'sepidar' ),
				'type' => Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .download a' => 'background: {{VALUE}};',
				],
			]
		);

    $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'dl_typo',
        'label' => esc_html__( 'تایپوگرافی', 'sepidar' ),
        'selector' => '{{WRAPPER}} .download a',
			]
		);

    $this->add_control(
			'item_padding',
			[
				'label' => esc_html__( 'فاصله داخلی (پدینگ)', 'sepidar' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .download a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);


		$this->end_controls_section();

	}

	protected function render() {
  $settings = $this->get_settings_for_display();
  global $post;
  ?>
  <?php if($settings['style']): ?>
  <div class="single_info">
    <div class="single_info__details">
    <div class="download">
        <?php if(get_field('download_128')): ?>
        <a download href="<?php the_field('download_128') ?>"><i class="bi bi-download"></i> <?php _e('دانلود با کیفیت ۱۲۸', 'musicsara') ?></a>
        <?php endif; ?>
        <?php if(get_field('download_320')): ?>
        <a download href="<?php the_field('download_320') ?>"><i class="bi bi-download"></i> <?php _e('دانلود با کیفیت ۳۲۰', 'musicsara') ?></a>
        <?php endif; ?>
        <?php if(get_field('download_flac')): ?>
        <a download href="<?php the_field('download_flac') ?>"><i class="bi bi-download"></i> <?php _e('دانلود با کیفیت FLAC', 'musicsara') ?></a>
        <?php endif; ?>
        <?php if(get_field('album_zip_128')): ?>
        <a download href="<?php the_field('album_zip_128') ?>"><i class="bi bi-download"></i> <?php _e('دانلود بصورت یکجا با کیفیت ۱۲۸', 'musicsara') ?></a>
        <?php endif; ?>
        <?php if(get_field('album_zip_320')): ?>
        <a download href="<?php the_field('album_zip_320') ?>"><i class="bi bi-download"></i> <?php _e('دانلود بصورت یکجا با کیفیت ۳۲۰', 'musicsara') ?></a>
        <?php endif; ?>
        <?php if(get_field('album_zip_flac')): ?>
        <a download href="<?php the_field('album_zip_flac') ?>"><i class="bi bi-download"></i> <?php _e('دانلود بصورت یکجا با کیفیت FLAC', 'musicsara') ?></a>
        <?php endif; ?>
      </div>

      <?php if( get_field('video_480') || get_field('video_720') || get_field('video_1080') || get_field('video_4k') ): ?>
      <div class="download_video__title">
        <p><?php _e('دانلود موزیک ویدیو', 'musicsara'); ?></p>
      </div>
      <div class="download">
        <?php if(get_field('video_4k')): ?>
          <a download href="<?php the_field('video_4k') ?>"><i class="bi bi-download"></i><?php _e('دانلود با کیفیت 4k', 'musicsara') ?></a>
          <?php endif; ?>
          <?php if(get_field('video_1080')): ?>
          <a download href="<?php the_field('video_1080') ?>"><i class="bi bi-download"></i> <?php _e('دانلود با کیفیت ۱۰۸۰', 'musicsara') ?></a>
          <?php endif; ?>
          <?php if(get_field('video_720')): ?>
          <a download href="<?php the_field('video_720') ?>"><i class="bi bi-download"></i> <?php _e('دانلود با کیفیت ۷۲۰', 'musicsara') ?></a>
          <?php endif; ?>
          <?php if(get_field('video_480')): ?>
          <a download href="<?php the_field('video_480') ?>"><i class="bi bi-download"></i> <?php _e('دانلود با کیفیت ۴۸۰', 'musicsara') ?></a>
          <?php endif; ?>
      </div>
      <?php endif; ?>


      <?php if(get_field('lyrics') && ($settings['show_lyrics'] == 'yes') ): ?>
      <div class="lryics_btn">
        <button data-bs-toggle="modal" data-bs-target="#exampleModal"><i class="bi bi-music-note-list"></i> <?php _e('مشاهده متن آهنگ', 'musicsara') ?></button>
      </div>
      <?php endif; ?>
    </div>
  </div>

  <?php if(get_field('lyrics')): ?>
<div class="modal fade" id="exampleModal" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true">
  <div class="modal-dialog modal-dialog-centered">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title" id="exampleModalLabel"> <?php _e('متن ترانه', 'musicsara') ?></h5>
        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
      </div>
      <div class="modal-body">
      <?php if(get_field('lyrics')): ?>
      <div class="single_info_lyrics">
        <?php the_field('lyrics') ?>
      </div>
      <?php endif; ?>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal"><?php _e('بستن', 'musicsara') ?></button>
      </div>
    </div>
  </div>
</div>
<?php endif; ?>
  
  <?php
  endif; //end modern style
	}
}