<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class RelatedPostsWidget extends \Elementor\Widget_Base {

	public function get_name() {
		return 'related_posts';
	}

  public function __construct($data = [], $args = null) {
    parent::__construct($data, $args);

    wp_register_script( 'elements', get_template_directory_uri() . '/assets/js/elements.js', [ 'elementor-frontend', 'swiper' ], '1.0.0', true );
  }

  public function get_script_depends() {
    return [ 'elements' ];
  }

	public function get_title() {
		return esc_html__( 'مطالب مرتبط', 'musicsara' );
	}

	public function get_icon() {
		return 'eicon-product-related';
	}

	public function get_custom_help_url() {
		return 'https://developers.elementor.com/docs/widgets/';
	}

	public function get_categories() {
		return [ 'musicsara' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'عمومی', 'musicsara' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

    $this->add_control(
      'title',
      [
        'label' => esc_html__('عنوان', 'elementor-oembed-widget'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => 'مطالب مرتبط',
        'frontend_available' => true,
      ]
    );

    $this->add_control(
      'post_count',
      [
        'label' => esc_html__('تعداد مطالب', 'elementor-oembed-widget'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => 10,
        'frontend_available' => true,
      ]
    );


		$this->end_controls_section();

    $this->start_controls_section(
      'c_settings',
      [
        'label' => esc_html__('تنظیمات کروسل', 'elementor-ads-widget'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    $this->add_control(
			'pagination_notice',
			[
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' =>  '<div>'. __('تنظیمات صفحه بندی و پیکان ها', 'sepidar') .'</div>',
				'content_classes' => 'sepidar_divider',
			]
		);

    $this->add_control(
			'show_pagination',
			[
				'label' => esc_html__( 'نمایش صفحه بندی', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
				'default' => 'yes',
        'frontend_available' => true
			]
		);

    $this->add_control(
			'show_next_prev',
			[
				'label' => esc_html__( 'نمایش دکمه بعدی قبلی', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
				'default' => 'yes',
        'frontend_available' => true
			]
		);

    $this->add_control(
			'carousel_items',
			[
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' =>  '<div>'. __('تنظیمات نمایش تعداد آیتم ها', 'sepidar') .'</div>',
				'content_classes' => 'sepidar_divider',
			]
		);


    $this->add_control(
      'el_desktop',
      [
        'label' => esc_html__('تعداد آیتم در دسکتاپ', 'elementor-oembed-widget'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'placeholder' => esc_html__('مثلا 6.3', 'elementor-oembed-widget'),
        'default' => '6.3',
        'frontend_available' => true,
        'description' => 'میتوانید از اعداد اعشاری برای نمایش بخشی از آیتم بعدی استفاده کنید مثلا ۶.۲  ۶محصول نمایش داده میشود و ۲۰٪ از آینم بعدی نیز نمایش داده میشود'
      ]
    );

    $this->add_control(
      'el_desktop_small',
      [
        'label' => esc_html__('تعداد آیتم در دسکتاپ کوچک', 'elementor-oembed-widget'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'placeholder' => esc_html__('مثلا 3.2', 'elementor-oembed-widget'),
        'default' => '4.2',
        'frontend_available' => true
      ]
    );

    $this->add_control(
      'el_tablet',
      [
        'label' => esc_html__('تعداد آیتم در تبلت', 'elementor-oembed-widget'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'placeholder' => esc_html__('مثلا 2.2', 'elementor-oembed-widget'),
        'default' => '2',
        'frontend_available' => true
      ]
    );

    $this->add_control(
      'el_mobile',
      [
        'label' => esc_html__('تعداد آیتم در موبایل', 'elementor-oembed-widget'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'placeholder' => esc_html__('مثلا 2.7', 'elementor-oembed-widget'),
        'default' => '1.5',
        'frontend_available' => true
      ]
    );

    $this->add_control(
			'carousel_autoplay_notice',
			[
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' =>  '<div>'. __('سایز تنظیمات کروسل', 'sepidar') .'</div>',
				'content_classes' => 'sepidar_divider',
			]
		);

    $this->add_control(
			'loop',
			[
				'label' => esc_html__( 'لوپ کردن آیتم های کروسل', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

    $this->add_control(
			'centeredSlides',
			[
				'label' => esc_html__( 'حرکت از آیتم وسط', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

    $this->add_control(
			'autoplay',
			[
				'label' => esc_html__( 'اتوپلی کردن آیتم ها', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

    $this->add_control(
			'autoplay_delay',
			[
				'label' => esc_html__( 'میزان تاخیر (ms)', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( '4000', 'textdomain' ),
        'condition' => [
          'autoplay' => 'yes',
        ],
				'placeholder' => esc_html__( 'بر اساس میلی ثانیه وارد کنید. هر ۱ثانیه معادل ۱۰۰۰ میلی ثانیه', 'textdomain' ),
			]
		);

    $this->end_controls_section();

	}

	protected function render() {
  $settings = $this->get_settings_for_display();
  global $post;
  $show_buttons = $settings['show_next_prev'];
  $widget_id = $this->get_id();
  $title = $settings['title'];
  $options = array(
    'el_mobile' => $settings['el_mobile'],
    'el_desktop_small' => $settings['el_desktop_small'],
    'el_tablet' => $settings['el_tablet'],
    'el_desktop' => $settings['el_desktop'],
    'autoplay' => ($settings['autoplay'] == 'yes') ? 'true' : 'false',
    'loop' => ($settings['loop'] == 'yes') ? 'true' : 'false',
    'autoplay_delay' => $settings['autoplay_delay'] ? $settings['autoplay_delay'] : '5000',
    'centeredSlides' => $settings['centeredSlides'] == 'yes' ? 'true' : 'false'
  );
  ?>

<?php
  $artist = get_the_terms($post->ID, 'artist');
  $artist_arr = [];
  if($artist){
    foreach($artist as $item){
      $artist_arr[] = $item->term_id;
    }
  }
  $args = array(
    'showposts' => $settings['post_count'] ? $settings['post_count']: 10,
    'post__not_in' => array($post->ID),
    'tax_query' => array(
      array(
        'taxonomy' => 'artist',
        'field' => 'id',
        'terms' => $artist_arr,
      )
    )
  );

  $query = new WP_Query($args);
  if($query->have_posts()):
  ?>


<!-- start -->
<section id="musicsara_carousel_<?php echo $widget_id; ?>"
    data-options="<?php echo htmlspecialchars( json_encode($options) ) ?>"
    class="musicsara_carousel musicsara_content_carousel bg_color latestSongs mb-5">
  <div class="swiper">
    <div class="latestSongs__header d-flex justify-content-between">
      <h3><span class="indicator"></span>
      <?php echo $title; ?>
      </h3>
      <div class="button_wrap d-flex">
      <?php if($show_buttons): ?>
        <div class="button-prev"><i class="bi bi-chevron-right"></i></div>
        <div class="button-next"><i class="bi bi-chevron-left"></i></div>
      <?php endif;?>
      </div>
    </div>
    <div class="swiper-wrapper">
    <?php
      if ($query->found_posts) :
        while ($query->have_posts()) :
          $query->the_post();
      ?>
          <div class="swiper-slide">
            <?php get_template_part('inc/template_parts/cards/default') ?>
          </div>
      <?php
        endwhile;
      endif;
      wp_reset_postdata();
      ?>
    </div>
    <?php if( $settings['show_pagination'] === 'yes' ): ?>
      <div class="swiper-pagination"></div>
    <?php endif; ?>
  </div>
</section>


<?php endif; ?>


  <?php
	}
}