<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor Slider Widget.
 *
 * @since 1.0.0
 */
class SliderWidget extends \Elementor\Widget_Base {

  public function __construct($data = [], $args = null) {
    parent::__construct($data, $args);

    wp_register_script( 'elements', get_template_directory_uri() . '/assets/js/elements.js', [ 'elementor-frontend', 'swiper' ], '1.0.0', true );
  }

  public function get_script_depends() {
    return [ 'elements' ];
  }

	/**
	 * Get widget name.
	 *
	 * Retrieve widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'slider';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'اسلایدر', 'musicsara' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-slider-push';
	}

	/**
	 * Get custom help URL.
	 *
	 * Retrieve a URL where the user can get more information about the widget.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget help URL.
	 */
	public function get_custom_help_url() {
		return 'https://developers.elementor.com/docs/widgets/';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'musicsara' ];
	}

	/**
	 * Get widget keywords.
	 *
	 * Retrieve the list of keywords the widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return array Widget keywords.
	 */
	public function get_keywords() {
		return [ 'oembed', 'url', 'link' ];
	}

	/**
	 * Register oEmbed widget controls.
	 *
	 * Add input fields to allow the user to customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function register_controls(){
    $this->start_controls_section(
      'c_settings',
      [
        'label' => esc_html__('تنظیمات کروسل', 'elementor-ads-widget'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    $this->add_control(
			'pagination_notice',
			[
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' =>  '<div>'. __('تنظیمات صفحه بندی و پیکان ها', 'sepidar') .'</div>',
				'content_classes' => 'sepidar_divider',
			]
		);

    $this->add_control(
			'show_pagination',
			[
				'label' => esc_html__( 'نمایش صفحه بندی', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
				'default' => 'yes',
        'frontend_available' => true
			]
		);

    $this->add_control(
			'show_next_prev',
			[
				'label' => esc_html__( 'نمایش دکمه بعدی قبلی', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
				'default' => 'yes',
        'frontend_available' => true
			]
		);

    $this->add_control(
			'carousel_items',
			[
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' =>  '<div>'. __('تنظیمات نمایش تعداد آیتم ها', 'sepidar') .'</div>',
				'content_classes' => 'sepidar_divider',
			]
		);


    $this->add_control(
      'el_desktop',
      [
        'label' => esc_html__('تعداد آیتم در دسکتاپ', 'elementor-oembed-widget'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'placeholder' => esc_html__('مثلا 3', 'elementor-oembed-widget'),
        'default' => '3',
        'frontend_available' => true,
        'description' => 'میتوانید از اعداد اعشاری برای نمایش بخشی از آیتم بعدی استفاده کنید مثلا ۶.۲  ۶محصول نمایش داده میشود و ۲۰٪ از آینم بعدی نیز نمایش داده میشود'
      ]
    );

    $this->add_control(
      'el_desktop_small',
      [
        'label' => esc_html__('تعداد آیتم در دسکتاپ کوچک', 'elementor-oembed-widget'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'placeholder' => esc_html__('مثلا 3.2', 'elementor-oembed-widget'),
        'default' => '3.2',
        'frontend_available' => true
      ]
    );

    $this->add_control(
      'el_tablet',
      [
        'label' => esc_html__('تعداد آیتم در تبلت', 'elementor-oembed-widget'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'placeholder' => esc_html__('مثلا 2.2', 'elementor-oembed-widget'),
        'default' => '1',
        'frontend_available' => true
      ]
    );

    $this->add_control(
      'el_mobile',
      [
        'label' => esc_html__('تعداد آیتم در موبایل', 'elementor-oembed-widget'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'placeholder' => esc_html__('مثلا 2.7', 'elementor-oembed-widget'),
        'default' => '1',
        'frontend_available' => true
      ]
    );

    $this->add_control(
			'carousel_autoplay_notice',
			[
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' =>  '<div>'. __('سایز تنظیمات کروسل', 'sepidar') .'</div>',
				'content_classes' => 'sepidar_divider',
			]
		);

    $this->add_control(
			'loop',
			[
				'label' => esc_html__( 'لوپ کردن آیتم های کروسل', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

    $this->add_control(
			'centeredSlides',
			[
				'label' => esc_html__( 'حرکت از آیتم وسط', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

    

    $this->add_control(
			'autoplay',
			[
				'label' => esc_html__( 'اتوپلی کردن آیتم ها', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

    $this->add_control(
			'autoplay_delay',
			[
				'label' => esc_html__( 'میزان تاخیر (ms)', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( '4000', 'textdomain' ),
        'condition' => [
          'autoplay' => 'yes',
        ],
				'placeholder' => esc_html__( 'بر اساس میلی ثانیه وارد کنید. هر ۱ثانیه معادل ۱۰۰۰ میلی ثانیه', 'textdomain' ),
			]
		);

    $this->end_controls_section();



    $this->start_controls_section(
			'section_styles',
			[
				'label' => esc_html__( 'استایل', 'sepidar' ),
				'tab' => Elementor\Controls_Manager::TAB_STYLE,
			]
		);

    $this->add_control(
			'greyscale_image',
			[
				'label' => esc_html__( 'تصویر سیاه سفید', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'بله', 'textdomain' ),
				'label_off' => esc_html__( 'خیر', 'textdomain' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);


    $this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'border',
				'selector' => '{{WRAPPER}} .swiper-slide img',
			]
		);

    $this->add_control(
			'image_settings',
			[
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' =>  '<div>'. __('تنظیمات تصویر', 'sepidar') .'</div>',
				'content_classes' => 'sepidar_divider',
			]
		);

    $this->add_control(
			'item_radius',
			[
				'label' => esc_html__( 'حاشیه', 'sepidar' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .swiper-slide img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

    $this->add_control(
			'item_padding',
			[
				'label' => esc_html__( 'فاصله داخلی (پدینگ)', 'sepidar' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .swiper-slide img' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

    $this->add_control(
			'item_margin',
			[
				'label' => esc_html__( 'فاصله خارجی (مارجین)', 'sepidar' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .swiper-slide img' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

    $this->add_control(
			'image_container_settings',
			[
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' =>  '<div>'. __('تنظیمات پس‌زمینه تصاویر', 'sepidar') .'</div>',
				'content_classes' => 'sepidar_divider',
			]
		);

    $this->add_control(
			'item_container_radius',
			[
				'label' => esc_html__( 'حاشیه', 'sepidar' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .swiper-slide' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

    $this->add_control(
			'item_container_padding',
			[
				'label' => esc_html__( 'فاصله داخلی (پدینگ)', 'sepidar' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .swiper-slide' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

    $this->add_control(
			'item_container_margin',
			[
				'label' => esc_html__( 'فاصله خارجی (مارجین)', 'sepidar' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .swiper-slide' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

    $this->add_control(
			'icon_bg_notice',
			[
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' =>  '<div>'. __('رنگ بندی', 'sepidar') .'</div>',
				'content_classes' => 'sepidar_divider',
			]
		);

    $this->add_control(
			'arrow_color',
			[
				'label' => esc_html__( 'رنگ پیکان ها', 'sepidar' ),
				'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
					'{{WRAPPER}} .swiper-button-prev' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .swiper-button-next' => 'background: {{VALUE}} !important',
				],
			]
		);

    $this->add_control(
			'arrow_color_hover',
			[
				'label' => esc_html__( 'رنگ هاور پیکان ها', 'sepidar' ),
				'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
					'{{WRAPPER}} .swiper-button-prev:hover' => 'background: {{VALUE}} !important',
					'{{WRAPPER}} .swiper-button-next:hover' => 'background: {{VALUE}} !important',
				],
			]
		);

    $this->add_control(
			'bullets_color',
			[
				'label' => esc_html__( 'رنگ صفحه بندی', 'sepidar' ),
				'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
					'{{WRAPPER}} .swiper-pagination-bullet ' => 'background: {{VALUE}} !important',
				],
			]
    );

    $this->add_control(
			'image_bg',
			[
				'label' => esc_html__( 'رنگ پس‌زمینه تصاویر', 'sepidar' ),
				'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
					'{{WRAPPER}} .swiper-slide' => 'background: {{VALUE}} !important',
				],
			]
    );

    $this->add_control(
			'size_notice',
			[
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' =>  '<div>'. __('سایزبندی', 'sepidar') .'</div>',
				'content_classes' => 'sepidar_divider',
			]
		);

    $this->add_control(
			'image_width',
			[
				'label' => esc_html__( 'طول تصویر', 'sepidar' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .swiper-slide img' => 'width: {{SIZE}}{{UNIT}} !important',
				],
			]
		);

    $this->add_control(
			'image_height',
			[
				'label' => esc_html__( 'ارتفاع تصویر', 'sepidar' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .swiper-slide img' => 'height: {{SIZE}}{{UNIT}} !important',
				],
			]
		);


    $this->add_control( 
      'object-fit', 
      [ 
        'label' => __( 'Object Fit تصویر', 'elementor' ), 
        'type' => \Elementor\Controls_Manager::SELECT, 
        'options' => [ 
          '' => __( 'Default', 'elementor' ), 
          'fill' => __( 'Fill', 'elementor' ), 
          'cover' => __( 'Cover', 'elementor' ), 
          'contain' => __( 'Contain', 'elementor' ), 
        ], 
        'default' => '', 
        'selectors' => [ 
          '{{WRAPPER}} .swiper-slide img' => 'object-fit: {{VALUE}};', 
        ], 
      ] 
    ); 

    $this->add_control(
			'arrow_designs_notice',
			[
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' =>  '<div>'. __('طراحی پیکان های عقب/جلو', 'sepidar') .'</div>',
				'content_classes' => 'sepidar_divider',
			]
		);

    $this->add_control(
			'arrow_width',
			[
				'label' => esc_html__( 'طول پیکان', 'sepidar' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
        'selectors' => [
					'{{WRAPPER}} .swiper-button-prev' => 'width: {{SIZE}}{{UNIT}} !important',
					'{{WRAPPER}} .swiper-button-next' => 'width: {{SIZE}}{{UNIT}} !important',
				],
			]
		);

    $this->add_control(
			'arrow_height',
			[
				'label' => esc_html__( 'ارتفاع پیکان', 'sepidar' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .swiper-button-prev' => 'height: {{SIZE}}{{UNIT}} !important',
					'{{WRAPPER}} .swiper-button-next' => 'height: {{SIZE}}{{UNIT}} !important',
				],
			]
		);

    $this->add_control(
			'arrow_radius',
			[
				'label' => esc_html__( 'حاشیه', 'sepidar' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .swiper-button-next' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
          '{{WRAPPER}} .swiper-button-prev' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
				],
			]
		);

		$this->end_controls_section();
  }

	/**
	 * Render widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();
		$html = wp_oembed_get( $settings['url'] );
    $widget_id = $this->get_id();
    $options = array(
      'el_mobile' => $settings['el_mobile'],
      'el_desktop_small' => $settings['el_desktop_small'],
      'el_tablet' => $settings['el_tablet'],
      'el_desktop' => $settings['el_desktop'],
      'autoplay' => ($settings['autoplay'] == 'yes') ? 'true' : 'false',
      'loop' => ($settings['loop'] == 'yes') ? 'true' : 'false',
      'autoplay_delay' => $settings['autoplay_delay'] ? $settings['autoplay_delay'] : '5000',
      'centeredSlides' => $settings['centeredSlides'] == 'yes' ? 'true' : 'false'
    );
    ?>

    <section id="musicsara_carousel_<?php echo $widget_id; ?>"
    data-options="<?php echo htmlspecialchars( json_encode($options) ) ?>"
    class="musicsara_carousel musicsara_logo_carousel bg_color slider">
      <div dir="ltr" class="swiper">
        <div class="swiper-wrapper">
          <?php
          $args = array(
            'showposts' => 6,
            'meta_key'    => 'show_slider',
            'meta_value'  => true,
          );

          $query = new WP_Query($args);
          if ($query->found_posts) :
            while ($query->have_posts()) :
              $query->the_post();
          ?>
            <div class="swiper-slide">
              <a href="<?php the_permalink(); ?>">
                <img src="<?php the_field('slider_image') ?>" alt="">
                <div class="slider_text">
                  <h3><?php the_title(); ?></h3>
                  <div class="d-flex justify-content-between align-items-center">
                    <div class="artist">
                      <?php echo strip_tags( get_the_term_list($post->ID, 'artist', '', ' ', '') ); ?>
                    </div>
                    <span>دانلود <i class="bi bi-chevron-left"></i></span>
                  </div>
                </div>
              </a>
            </div>
          <?php
            endwhile;
          endif;
          wp_reset_postdata();
          ?>
        </div>
        <?php if( $settings['show_next_prev'] == 'yes' ): ?>
          <div class="button-prev"><i class="bi bi-chevron-right"></i></div>
          <div class="button-next"><i class="bi bi-chevron-left"></i></div>
        <?php endif; ?>
      </div>
    </section>

  <?php
	}

}