<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor Slider Widget.
 *
 * @since 1.0.0
 */
class SocialWidget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'social_carousel';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'شبکه های اجتماعی', 'musicsara' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-social-icons';
	}

	/**
	 * Get custom help URL.
	 *
	 * Retrieve a URL where the user can get more information about the widget.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget help URL.
	 */
	public function get_custom_help_url() {
		return 'https://developers.elementor.com/docs/widgets/';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'musicsara' ];
	}

	/**
	 * Get widget keywords.
	 *
	 * Retrieve the list of keywords the widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return array Widget keywords.
	 */
	public function get_keywords() {
		return [ 'oembed', 'url', 'link' ];
	}

	/**
	 * Register oEmbed widget controls.
	 *
	 * Add input fields to allow the user to customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'تنظیمات', 'musicsara' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->end_controls_section();

	}

	/**
	 * Render widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();
    $config =  get_option('my_framework');
    ?>


    <div class="social">
      <div class="social_desc"><?php _e('شبکه های اجتماعی', 'musicsara'); ?></div>
      <div class="social_list">
        <ul>
          <?php if ($config['telegram']) : ?>
            <li><a class="telegram" href="<?= $config['telegram']; ?>"><i class="bi bi-telegram"></i></a></li>
          <?php endif; ?>
          <?php if ($config['instagram']) : ?>
            <li><a class="instagram" href="<?= $config['instagram']; ?>"><i class="bi bi-instagram"></i></a></li>
          <?php endif; ?>
          <?php if ($config['twitter']) : ?>
            <li><a class="twitter" href="<?= $config['twitter']; ?>"><i class="bi bi-twitter"></i></a></li>
          <?php endif; ?>
          <?php if ($config['facebook']) : ?>
            <li><a class="facebook" href="<?= $config['facebook']; ?>"><i class="bi bi-facebook"></i></a></li>
          <?php endif; ?>
        </ul>
      </div>
    </div>

  <?php
	}

}