<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor Slider Widget.
 *
 * @since 1.0.0
 */
class SpecialMusicWidget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'special_music';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'مطالب ویژه', 'musicsara' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-grid';
	}

	/**
	 * Get custom help URL.
	 *
	 * Retrieve a URL where the user can get more information about the widget.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget help URL.
	 */
	public function get_custom_help_url() {
		return 'https://developers.elementor.com/docs/widgets/';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'musicsara' ];
	}

	/**
	 * Get widget keywords.
	 *
	 * Retrieve the list of keywords the widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return array Widget keywords.
	 */
	public function get_keywords() {
		return [ 'oembed', 'url', 'link' ];
	}

	/**
	 * Register oEmbed widget controls.
	 *
	 * Add input fields to allow the user to customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'تنظیمات', 'musicsara' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'carousel_title',
			[
				'label' => esc_html__( 'عنوان کروسل', 'musicsara' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				// 'input_type' => 'text',
				// 'placeholder' => esc_html__( '', 'musicsara' ),
			]
		);

    $this->add_control(
			'carousel_items',
			[
				'label' => esc_html__( 'تعداد مطالب', 'musicsara' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				// 'input_type' => 'text',
        'default' => 10,
				// 'placeholder' => esc_html__( '', 'musicsara' ),
			]
		);


    $this->add_control(
      'special',
      [
        'label' => esc_html__('نمایش فقط مطالب ویژه', 'musicsara'),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__('بله', 'musicsara'),
        'label_off' => esc_html__('خیر', 'musicsara'),
        'return_value' => true,
        'default' => false,
      ]
    );

    $options = array();

    $args = array(
      'hide_empty' => false,
      'post_type'     => 'post',
      'taxonomy'  => 'category',

    );



    $categories = get_categories($args);

    foreach ($categories as $key => $category) {
      $options[$category->term_id] = $category->name;
    }
  
    $type_ = array();

    $musicsara_types = get_terms(array(
      'taxonomy'   => 'type_',
      'hide_empty' => false
    ));

    foreach ($musicsara_types as $key => $type) {
      $type_[$type->term_id] = $type->name;
    }

   

    $this->add_control(
      'category',
      [
        'label' => esc_html__('انتخاب دسته بندی', 'musicsara'),
        'type' => \Elementor\Controls_Manager::SELECT2,
        'multiple' => false,
        'description' => 'در صورت انتخاب دسته مطالب دسته و درصورت انتخاب نکردن آخرین مطالب نشان داده می‌شوند.',
        'options' => $options,
        'default' => [],
      ]
    );

    $this->add_control(
      'post_type',
      [
        'label' => esc_html__('انتخاب نوع پست', 'musicsara'),
        'type' => \Elementor\Controls_Manager::SELECT2,
        'multiple' => false,
        'description' => 'می‌توانید مطالب را بر اساس نوع پست نیز نمایش دهید. مثلا تک آهنگ ها موزیک ها و...',
        'options' => $type_,
        'default' => [],
      ]
    );


		$this->end_controls_section();

	}

	/**
	 * Render widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();
		$title = $settings['carousel_title'];
    $category = $settings['category'];
    $post_type = $settings['post_type'];
    $just_special = $settings['special'];

    global $post;
    ?>
  <section class="topOfWeek">
      <div class="topOfWeek__header d-flex justify-content-between">
        <h3><span class="indicator"></span>
        <?php echo $title; ?>
        </h3>
      </div>
      <?php

      $args = array(
        'showposts' => $settings['carousel_items'],
      );

      if($just_special) {
        $args['meta_key'] = 'special';
        $args['meta_value'] = true;
      }

      if($category){
        $args['cat'] = $category;
      }

      if($post_type){
        $args['tax_query'] = array(
          array(
            'taxonomy' => 'type_',
            'field' => 'term_id',
            'terms' => $post_type
          ),
        );
      }

      $query = new WP_Query($args);
      if ($query->found_posts) :
        while ($query->have_posts()) :
          $query->the_post();
      ?>
          <div class="topOfWeek__item d-flex justify-content-between align-items-center">
            <div class="rightSide d-flex align-items-center">
              <a href="<?php the_permalink() ?>">
                <?php the_post_thumbnail('cover_small') ?>
              </a>
              <div class="topOfWeek__artist">
                <a class="topOfWeek__title" href="<?php the_permalink() ?>"><?php the_field('title') ?></a>
              </div>
              <div class="topOfWeek__name">
                <?php echo get_the_term_list(get_the_ID(), 'artist', '', ' ', ''); ?>
              </div>

            </div>
            <div class="leftSide d-flex">
              <span class="topOfWeek__like">
                <?php echo like_it_button_html('', $post); ?>
              </span>
              <span data-state="" data-id="<?= get_the_ID(); ?>" data-nonce="<?= wp_create_nonce('playonline') ?>" data-link="" data-name="" class="me-2 play_icon play_single_music"><i class="bi bi-play-fill"></i></span>
              <a class="topOfWeek__download" href="<?php the_permalink() ?>"><i class="bi bi-download"></i></a>
            </div>
          </div>
      <?php
        endwhile;
      endif;
      wp_reset_postdata();
      ?>
  </section>

  <?php
	}

}